yakumo.cinder.v2.volume.Manager

Package yakumo :: Package cinder :: Package v2 :: Module volume :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for volumes on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for volumes on Block Storage V2 API

Instance Methods | [hide private]
_attr2json(self, attrs) | source code
_json2attr(self, json_params) | source code
yakumo.cinder.v2.volume.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, is_replication=`'``__UNDEF__``'`, consistency_group=`'``__UNDEF__``'`, scheduler_hints=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_multiattach=`'``__UNDEF__``'`) Create a volume | source code
yakumo.cinder.v2.volume.Resource |
manage(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, ref=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_bootable=`'``__UNDEF__``'`) Manage a volume | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_find_gen`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``name``'``,` `'``name``'``,` <yakumo.mapper.NoopClass obj`...``
| _json_resource_key = ``'``volume``'``
| _json_resources_key = ``'``volumes``'``
| _url_resource_list_path = ``'``/volumes/detail``'``
| _url_resource_path = ``'``/volumes``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _attr2json(self, attrs) | source code
Overrides: base.Manager._attr2json

### _json2attr(self, json_params) | source code
Overrides: base.Manager._json2attr

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, is_replication=`'``__UNDEF__``'`, consistency_group=`'``__UNDEF__``'`, scheduler_hints=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_multiattach=`'``__UNDEF__``'`) | source code
Create a volume Parameters: `name` (str) - Volume name `description` (str) - Description `volume_type` (yakumo.cinder.v2.volume_type.Resource) - Volume type `size` (int) - Size in GB `availability_zone` (yakumo.availability_zone.Resource) - Availability zone `source` (one of yakumo.image.Resource, yakumo.volume_snapshot.Resource and yakumo.volume.Resource) - Source image/snapshot/volume (optional) `is_replication` - Whether the volume is a replica of another volume `consistency_group` (yakumo.cinder.v2.consistency_group.Resource) - Consistency group (optional) `scheduler_hints` (dict) - Scheduler hints (optional) `metadata` (dict) - Metadata (key=value) `is_multiattach` (bool) - Whether multiattach is allowed Returns: yakumo.cinder.v2.volume.Resource Created volume Overrides: base.Manager.create

### manage(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`, ref=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_bootable=`'``__UNDEF__``'`) | source code
Manage a volume Parameters: `name` (str) - Volume name `description` (str) - Description `volume_type` (yakumo.cinder.v2.volume_type.Resource) - Volume type `size` (int) - Size in GB `availability_zone` (yakumo.availability_zone.Resource) - Availability zone `metadata` (dict) - Metadata (key=value) `host` (str) - Reference for volume host `ref` (dict) - Reference for existing volume (key=value) `is_bootable` (bool) - Whether volume is bootable Returns: yakumo.cinder.v2.volume.Resource Created volume

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('name', 'name', mapper.Noop), ('description', 'description', mapper.
      Noop), ('volume_type', 'volume_type', mapper.Noop), ('size', 'size', m
      apper.Noop), ('availability_zone', 'availability_zone', mapper.Resourc
      e('availability_zone')), ('source_image', 'imageRef', mapper.Resource(
      'image')), ('source_volume', 'source_volid', mapper.Resource('cinder.v
      olume')), ('source_snapshot', 'snapshot_id', mapper.Resource('cinder.v
      olume_snapshot')), ('source_replica', 'source_replica', mapper.Noop),
      ('consistencygroup', 'consistencygroup_id', mapper.Resource('cinder.co
      ...